/***************************************************************************
* Copyright (c) 2016, Wolf Vollprecht, Johan Mabille and Sylvain Corlay    *
*                                                                          *
* Distributed under the terms of the BSD 3-Clause License.                 *
*                                                                          *
* The full license is in the file LICENSE, distributed with this software. *
****************************************************************************/

#ifndef XTENSOR_R_CONFIG_HPP
#define XTENSOR_R_CONFIG_HPP

#define XTENSOR_R_VERSION_MAJOR 0
#define XTENSOR_R_VERSION_MINOR 9
#define XTENSOR_R_VERSION_PATCH 0

#ifndef XTENSOR_WARN_ON_COERCE
#define XTENSOR_WARN_ON_COERCE 1
#endif

#endif
